import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { Hostable } from "../../Hostable";
import { Door } from "../../misc/Door";
import { AutoDoorsSystem, DoorsSystem, ElectricalDoorsSystem } from "../../systems";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerData } from "../../PlayerData";
import { DoorsEvent } from "./DoorsEvent";
/**
 * Emitted when a player closes a specific door.
 */
export declare class DoorsDoorCloseEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, DoorsEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly doorsystem: AutoDoorsSystem<RoomType> | DoorsSystem<RoomType> | ElectricalDoorsSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that closed the door. Only available if the client is the
     * host.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The door that the player closed.
     */
    readonly door: Door<RoomType>;
    static eventName: "doors.close";
    eventName: "doors.close";
    private _alteredDoor;
    constructor(room: RoomType, doorsystem: AutoDoorsSystem<RoomType> | DoorsSystem<RoomType> | ElectricalDoorsSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that closed the door. Only available if the client is the
     * host.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The door that the player closed.
     */
    door: Door<RoomType>);
    /**
     * The alternate door that will be closed, if changed.
     */
    get alteredDoor(): Door<RoomType>;
    /**
     * Change the door that was closed.
     * @param door The door to close.
     */
    setDoor(door: Door<RoomType> | number): void;
}
//# sourceMappingURL=Close.d.ts.map