import { BasicEvent } from "@skeldjs/events";
import { SnapToMessage } from "@skeldjs/protocol";
import { Vector2 } from "@skeldjs/util";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player snaps to a position, without lerping. Typically emitted
 * when the player is moves between vents.
 */
export declare class PlayerSnapToEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SnapToMessage | undefined;
    /**
     * The old position of the player.
     */
    readonly oldPosition: Vector2;
    /**
     * The new position of the player.
     */
    readonly newPosition: Vector2;
    static eventName: "player.snapto";
    eventName: "player.snapto";
    private _alteredPosition;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SnapToMessage | undefined, 
    /**
     * The old position of the player.
     */
    oldPosition: Vector2, 
    /**
     * The new position of the player.
     */
    newPosition: Vector2);
    /**
     * The altered position that the player will snap to instead, if changed.
     */
    get alteredPosition(): Vector2;
    /**
     * Revert the player's position back to their old position.
     */
    revert(): void;
    /**
     * Set the position that the player was snapped to.
     * @param position The position to snap to.
     */
    setPosition(position: Vector2): void;
}
//# sourceMappingURL=SnapTo.d.ts.map