import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { ReactorConsoleAddEvent, ReactorConsoleRemoveEvent, ReactorConsolesResetEvent } from "../events";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface ReactorSystemData {
    timer: number;
    completed: Set<number>;
}
export declare type ReactorSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[
    ReactorConsoleAddEvent<RoomType>,
    ReactorConsoleRemoveEvent<RoomType>,
    ReactorConsolesResetEvent<RoomType>
]>;
/**
 * Represents a system responsible for handling reactor consoles.
 *
 * See {@link ReactorSystemEvents} for events to listen to.
 */
export declare class ReactorSystem<RoomType extends Hostable = Hostable> extends SystemStatus<ReactorSystemData, ReactorSystemEvents, RoomType> implements ReactorSystemData {
    /**
     * The timer before the reactor explodes.
     */
    timer: number;
    /**
     * The completed consoles.
     */
    completed: Set<number>;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | ReactorSystemData);
    get sabotaged(): boolean;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    private _addConsole;
    /**
     * Add a completed console. (Same as a player placing their hand on a
     * console)
     * @param consoleId The ID of the console to add.
     */
    addConsole(consoleId: number): Promise<void>;
    private _removeConsole;
    /**
     * Remove a completed console. (Same as a player removing their hand from a
     * console)
     * @param consoleId The ID of the console to add.
     */
    removeConsole(consoleId: number): Promise<void>;
    HandleSabotage(player: PlayerData<RoomType> | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    private _repair;
    repair(): Promise<void>;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
    private _lastUpdate;
    Detoriorate(delta: number): void;
}
//# sourceMappingURL=ReactorSystem.d.ts.map