import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface SabotageSystemData {
    cooldown: number;
}
export declare type SabotageSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[]>;
/**
 * Represents a system responsible for handling system sabotages.
 *
 * See {@link SabotageSystemEvents} for events to listen to.
 */
export declare class SabotageSystem<RoomType extends Hostable = Hostable> extends SystemStatus<SabotageSystemData, SabotageSystemEvents, RoomType> implements SabotageSystemData {
    /**
     * The cooldown before another sabotage can happen.
     */
    cooldown: number;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | SabotageSystemData);
    /**
     * Check whether any systems are currently sabotaged.
     */
    get anySabotaged(): boolean;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
    Detoriorate(delta: number): void;
}
//# sourceMappingURL=SabotageSystem.d.ts.map